@@ -5,14 +5,14 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-guardduty", "1.61.1", __name__[0:-6], "aws-guardduty@1.61.1.jsii.tgz"
+    "@aws-cdk/aws-guardduty", "1.95.1", __name__[0:-6], "aws-guardduty@1.95.1.jsii.tgz"
 )
 
 __all__ = [
